@@ -28,13 +28,17 @@ from typing import (
     List,
     Optional,
     Tuple,
-    Type,
     TypeVar,
     Union,
     get_args,
     overload,
 )
 
+try:
+    import annotationlib
+except ImportError:
+    annotationlib = None
+
 try:
     from types import UnionType
 except ImportError:
@@ -333,7 +337,17 @@ class DocumentOptions:
         #     # ignore attributes
         #     field10: ClassVar[string] = "a regular class variable"
         annotations = attrs.get("__annotations__", {})
-        fields = set([n for n in attrs if isinstance(attrs[n], Field)])
+        if not annotations and annotationlib:
+            # Python 3.14+ uses annotationlib
+            annotate = annotationlib.get_annotate_from_class_namespace(attrs)
+            if annotate:
+                annotations = (
+                    annotationlib.call_annotate_function(
+                        annotate, format=annotationlib.Format.VALUE
+                    )
+                    or {}
+                )
+        fields = {n for n in attrs if isinstance(attrs[n], Field)}
         fields.update(annotations.keys())
         field_defaults = {}
         for name in fields:
@@ -607,7 +621,7 @@ class DocumentBase(ObjectBase):
 
     @classmethod
     def _get_field_names(
-        cls, for_esql: bool = False, nested_class: Optional[Type[InnerDoc]] = None
+        cls, for_esql: bool = False, nested_class: Optional[type[InnerDoc]] = None
     ) -> List[str]:
         """Return the list of field names used by this document.
         If the document has nested objects, their fields are reported using dot
