@@ -44,14 +44,14 @@ def pytest_argv():
     ]
 
 
-@nox.session(python=["3.9", "3.10", "3.11", "3.12", "3.13"])
+@nox.session(python=["3.9", "3.10", "3.11", "3.12", "3.13", "3.14"])
 def test(session):
     session.install("-e", ".[dev]", env=INSTALL_ENV, silent=False)
 
     session.run(*pytest_argv(), *session.posargs)
 
 
-@nox.session(python=["3.9", "3.13"])
+@nox.session(python=["3.10", "3.14"])
 def test_otel(session):
     session.install(
         ".[dev]",
